@@ -65,6 +65,7 @@ class Test(unittest.TestCase):
         self.assertTrue(hasattr(resampler, 'get_count'))
         self.assertTrue(hasattr(resampler, 'get_min'))
         self.assertTrue(hasattr(resampler, 'get_max'))
+        self.assertTrue(hasattr(resampler, 'get_abs_max'))
         self.assertTrue(hasattr(resampler, 'get_average'))
         self.assertTrue(hasattr(resampler, 'get_fractions'))
         self.assertIsNone(resampler.counts)
@@ -189,7 +190,7 @@ class Test(unittest.TestCase):
 
     def _get_min_result(self, data, **kwargs):
         """Compute the bucket average with kwargs and check that no dask computation is performed."""
-        with dask.config.set(scheduler=CustomScheduler(max_computes=1)):
+        with dask.config.set(scheduler=CustomScheduler(max_computes=0)):
             result = self.resampler.get_min(data, **kwargs)
         return result.compute()
 
@@ -198,16 +199,16 @@ class Test(unittest.TestCase):
         data = da.from_array(np.array([[2, 11], [5, np.nan]]),
                              chunks=self.chunks)
         result = self._get_min_result(data)
-        # test multiple entries average
+        # test multiple entries minimum
         self.assertEqual(np.count_nonzero(result == 2), 1)
-        # test single entry average
+        # test single entry minimum
         self.assertEqual(np.count_nonzero(result == 5), 1)
         # test that minimum of bucket with only nan is nan, and empty buckets are nan
         self.assertEqual(np.count_nonzero(~np.isnan(result)), 2)
 
     def _get_max_result(self, data, **kwargs):
-        """Compute the bucket average with kwargs and check that no dask computation is performed."""
-        with dask.config.set(scheduler=CustomScheduler(max_computes=1)):
+        """Compute the bucket max with kwargs and check that no dask computation is performed."""
+        with dask.config.set(scheduler=CustomScheduler(max_computes=0)):
             result = self.resampler.get_max(data, **kwargs)
         return result.compute()
 
@@ -216,13 +217,31 @@ class Test(unittest.TestCase):
         data = da.from_array(np.array([[2, 11], [5, np.nan]]),
                              chunks=self.chunks)
         result = self._get_max_result(data)
-        # test multiple entries average
+        # test multiple entries maximum
         self.assertEqual(np.count_nonzero(result == 11), 1)
-        # test single entry average
+        # test single entry maximum
         self.assertEqual(np.count_nonzero(result == 5), 1)
         # test that minimum of bucket with only nan is nan, and empty buckets are nan
         self.assertEqual(np.count_nonzero(~np.isnan(result)), 2)
 
+    def test_get_abs_max(self):
+        """Test abs max bucket resampling."""
+        data = da.from_array(np.array([[2, -11], [5, np.nan]]),
+                             chunks=self.chunks)
+        result = self._get_abs_max_result(data)
+        # test multiple entries absolute maximum
+        self.assertEqual(np.count_nonzero(result == -11), 1)
+        # test single entry maximum
+        self.assertEqual(np.count_nonzero(result == 5), 1)
+        # test that minimum of bucket with only nan is nan, and empty buckets are nan
+        self.assertEqual(np.count_nonzero(~np.isnan(result)), 2)
+
+    def _get_abs_max_result(self, data, **kwargs):
+        """Compute the bucket abs max with kwargs and check that no dask computation is performed."""
+        with dask.config.set(scheduler=CustomScheduler(max_computes=0)):
+            result = self.resampler.get_abs_max(data, **kwargs)
+        return result.compute()
+
     def _get_average_result(self, data, **kwargs):
         """Compute the bucket average with kwargs and check that no dask computation is performed."""
         with dask.config.set(scheduler=CustomScheduler(max_computes=0)):
