@@ -15,7 +15,8 @@
 """Test AreaDefinition objects."""
 import io
 import sys
-from unittest.mock import MagicMock, patch
+from glob import glob
+from unittest.mock import patch
 
 import dask.array as da
 import numpy as np
@@ -23,61 +24,13 @@ import pytest
 import xarray as xr
 from pyproj import CRS, Proj
 
+import pyresample
 from pyresample import geo_filter, parse_area_file
 from pyresample.future.geometry import AreaDefinition, SwathDefinition
-from pyresample.future.geometry.area import (
-    get_full_geostationary_bounding_box_in_proj_coords,
-    get_geostationary_angle_extent,
-    get_geostationary_bounding_box_in_lonlats,
-    get_geostationary_bounding_box_in_proj_coords,
-    ignore_pyproj_proj_warnings,
-)
+from pyresample.future.geometry.area import ignore_pyproj_proj_warnings
 from pyresample.future.geometry.base import get_array_hashable
-
-
-@pytest.fixture
-def stere_area(create_test_area):
-    """Create basic polar-stereographic area definition."""
-    return create_test_area(
-        {
-            'a': '6378144.0',
-            'b': '6356759.0',
-            'lat_0': '50.00',
-            'lat_ts': '50.00',
-            'lon_0': '8.00',
-            'proj': 'stere'
-        },
-        800,
-        800,
-        (-1370912.72, -909968.64000000001, 1029087.28, 1490031.3600000001),
-        attrs={"name": 'areaD'},
-    )
-
-
-@pytest.fixture
-def geos_src_area(create_test_area):
-    """Create basic geostationary area definition."""
-    x_size = 3712
-    y_size = 3712
-    area_extent = (-5570248.477339745, -5561247.267842293, 5567248.074173927, 5570248.477339745)
-    proj_dict = {'a': 6378169.0, 'b': 6356583.8, 'h': 35785831.0,
-                 'lon_0': 0.0, 'proj': 'geos', 'units': 'm'}
-    return create_test_area(
-        proj_dict,
-        x_size,
-        y_size,
-        area_extent,
-    )
-
-
-@pytest.fixture
-def laea_area(create_test_area):
-    """Create basic LAEA area definition."""
-    x_size = 10
-    y_size = 10
-    area_extent = [1000000, 0, 1050000, 50000]
-    proj_dict = {"proj": 'laea', 'lat_0': '60', 'lon_0': '0', 'a': '6371228.0', 'units': 'm'}
-    return create_test_area(proj_dict, x_size, y_size, area_extent)
+from pyresample.geometry import AreaDefinition as LegacyAreaDefinition
+from pyresample.test.utils import assert_future_geometry
 
 
 class TestAreaHashability:
@@ -400,6 +353,45 @@ class TestAreaDefinition:
         latlong_crs = area_def.to_cartopy_crs()
         np.testing.assert_allclose(latlong_crs.bounds, [-180, 180, -90, 90])
 
+    def test_to_odc_geobox_odc_missing(self, monkeypatch, stere_area):
+        """Test odc-geo not installed."""
+        area = stere_area
+
+        with monkeypatch.context() as m:
+            m.setattr(pyresample.geometry, "odc_geo", None)
+
+            with pytest.raises(ModuleNotFoundError):
+                area.to_odc_geobox()
+
+    def test_to_odc_geobox(self, stere_area, create_test_area):
+        """Test conversion from area definition to odc GeoBox."""
+        from odc.geo.geobox import GeoBox
+
+        europe = stere_area
+        seviri = create_test_area(
+            {
+                'proj': 'geos',
+                'lon_0': 0.0,
+                'a': 6378169.00,
+                'b': 6356583.80,
+                'h': 35785831.00,
+                'units': 'm'},
+            123,
+            123,
+            (-5500000, -5500000, 5500000, 5500000))
+
+        for area_def in [europe, seviri]:
+            geobox = area_def.to_odc_geobox()
+
+            assert isinstance(geobox, GeoBox)
+
+            # Affine coefficiants
+            af = geobox.affine
+            assert af.a == area_def.pixel_size_x
+            assert af.e == -area_def.pixel_size_y
+            assert af.xoff == area_def.area_extent[0]
+            assert af.yoff == area_def.area_extent[3]
+
     def test_dump(self, create_test_area):
         """Test exporting area defs."""
         from io import StringIO
@@ -876,41 +868,31 @@ class TestAreaDefinition:
         assert (x__.data == x_expects).all()
         assert (y__.data == y_expects).all()
 
-    def test_get_slice_starts_stops(self, create_test_area):
+    @pytest.mark.parametrize(
+        "src_extent",
+        [
+            # Source and target have the same orientation
+            (-5580248.477339745, -5571247.267842293, 5577248.074173927, 5580248.477339745),
+            # Source is flipped in X direction
+            (5577248.074173927, -5571247.267842293, -5580248.477339745, 5580248.477339745),
+            # Source is flipped in Y direction
+            (-5580248.477339745, 5580248.477339745, 5577248.074173927, -5571247.267842293),
+            # Source is flipped in both X and Y directions
+            (5577248.074173927, 5580248.477339745, -5580248.477339745, -5571247.267842293),
+        ]
+    )
+    def test_get_slice_starts_stops(self, create_test_area, src_extent):
         """Check area slice end-points."""
+        from pyresample.future.geometry._subset import _get_slice_starts_stops
         x_size = 3712
         y_size = 3712
         area_extent = (-5570248.477339745, -5561247.267842293, 5567248.074173927, 5570248.477339745)
         proj_dict = {'a': 6378169.0, 'b': 6356583.8, 'h': 35785831.0,
                      'lon_0': 0.0, 'proj': 'geos', 'units': 'm'}
         target_area = create_test_area(proj_dict, x_size, y_size, area_extent)
-
-        # Expected result is the same for all cases
-        expected = (3, 3709, 3, 3709)
-
-        # Source and target have the same orientation
-        area_extent = (-5580248.477339745, -5571247.267842293, 5577248.074173927, 5580248.477339745)
-        source_area = create_test_area(proj_dict, x_size, y_size, area_extent)
-        res = source_area._get_slice_starts_stops(target_area)
-        assert res == expected
-
-        # Source is flipped in X direction
-        area_extent = (5577248.074173927, -5571247.267842293, -5580248.477339745, 5580248.477339745)
-        source_area = create_test_area(proj_dict, x_size, y_size, area_extent)
-        res = source_area._get_slice_starts_stops(target_area)
-        assert res == expected
-
-        # Source is flipped in Y direction
-        area_extent = (-5580248.477339745, 5580248.477339745, 5577248.074173927, -5571247.267842293)
-        source_area = create_test_area(proj_dict, x_size, y_size, area_extent)
-        res = source_area._get_slice_starts_stops(target_area)
-        assert res == expected
-
-        # Source is flipped in both X and Y directions
-        area_extent = (5577248.074173927, 5580248.477339745, -5580248.477339745, -5571247.267842293)
-        source_area = create_test_area(proj_dict, x_size, y_size, area_extent)
-        res = source_area._get_slice_starts_stops(target_area)
-        assert res == expected
+        source_area = create_test_area(proj_dict, x_size, y_size, src_extent)
+        res = _get_slice_starts_stops(source_area, target_area)
+        assert res == (3, 3709, 3, 3709)
 
     def test_proj_str(self, create_test_area):
         """Test the 'proj_str' property of AreaDefinition."""
@@ -1209,8 +1191,7 @@ class TestAreaDefinitionMetadata:
         }
         area_def = AreaDefinition(
             4326,
-            200,
-            100,
+            (100, 200),
             (-1000, -500, 1500, 2000),
             attrs=my_meta,
         )
@@ -1220,8 +1201,7 @@ class TestAreaDefinitionMetadata:
         """Test not passing metadata to AreaDefinition still results in a usable mapping."""
         area_def = AreaDefinition(
             4326,
-            200,
-            100,
+            (100, 200),
             (-1000, -500, 1500, 2000),
         )
         assert area_def.attrs == {}
@@ -1230,15 +1210,13 @@ class TestAreaDefinitionMetadata:
         """Test that metadata differences don't contribute to inequality."""
         area_def1 = AreaDefinition(
             4326,
-            200,
-            100,
+            (100, 200),
             (-1000, -500, 1500, 2000),
             attrs={"a": 1},
         )
         area_def2 = AreaDefinition(
             4326,
-            200,
-            100,
+            (100, 200),
             (-1000, -500, 1500, 2000),
             attrs={"a": 2},
         )
@@ -1249,27 +1227,19 @@ class TestAreaDefinitionMetadata:
 class TestMakeSliceDivisible:
     """Test the _make_slice_divisible."""
 
-    def test_make_slice_divisible(self):
+    @pytest.mark.parametrize(
+        ("sli", "factor"),
+        [
+            (slice(10, 21), 2),
+            (slice(10, 23), 3),
+            (slice(10, 23), 5),
+        ]
+    )
+    def test_make_slice_divisible(self, sli, factor):
         """Test that making area shape divisible by a given factor works."""
-        from pyresample.geometry import _make_slice_divisible
+        from pyresample.future.geometry._subset import _make_slice_divisible
 
         # Divisible by 2
-        sli = slice(10, 21)
-        factor = 2
-        assert (sli.stop - sli.start) % factor != 0
-        res = _make_slice_divisible(sli, 1000, factor=factor)
-        assert (res.stop - res.start) % factor == 0
-
-        # Divisible by 3
-        sli = slice(10, 23)
-        factor = 3
-        assert (sli.stop - sli.start) % factor != 0
-        res = _make_slice_divisible(sli, 1000, factor=factor)
-        assert (res.stop - res.start) % factor == 0
-
-        # Divisible by 5
-        sli = slice(10, 23)
-        factor = 5
         assert (sli.stop - sli.start) % factor != 0
         res = _make_slice_divisible(sli, 1000, factor=factor)
         assert (res.stop - res.start) % factor == 0
@@ -1363,9 +1333,13 @@ class TestCreateAreaDef:
         should_fail = isinstance(center, str) or len(center) != 2
         if should_fail:
             pytest.raises(ValueError, cad, *args, **kwargs)
-        else:
+            return
+
+        future_geometries = isinstance(base_def, AreaDefinition)
+        with pyresample.config.set({"features.future_geometries": future_geometries}):
             area_def = cad(*args, **kwargs)
-            self._compare_area_defs(area_def, base_def, use_proj4="EPSG" in projection)
+        assert_future_geometry(area_def, future_geometries)
+        self._compare_area_defs(area_def, base_def, use_proj4="EPSG" in projection)
 
     def test_create_area_def_extra_combinations(self, create_test_area):
         """Test extra combinations of create_area_def parameters."""
@@ -1437,180 +1411,6 @@ class TestCreateAreaDef:
         assert area_def.shape == (101, 90)
 
 
-@pytest.fixture
-def truncated_geos_area(create_test_area):
-    """Create a truncated geostationary area."""
-    projection = {'a': '6378169', 'h': '35785831', 'lon_0': '9.5', 'no_defs': 'None', 'proj': 'geos',
-                  'rf': '295.488065897014', 'type': 'crs', 'units': 'm', 'x_0': '0', 'y_0': '0'}
-    area_extent = (5567248.0742, 5570248.4773, -5570248.4773, 1393687.2705)
-    width = 3712
-    height = 1392
-    geos_area = create_test_area(projection, width, height, area_extent)
-    return geos_area
-
-
-@pytest.fixture
-def truncated_geos_area_in_space(create_test_area):
-    """Create a truncated geostationary area."""
-    projection = {'a': '6378169', 'h': '35785831', 'lon_0': '9.5', 'no_defs': 'None', 'proj': 'geos',
-                  'rf': '295.488065897014', 'type': 'crs', 'units': 'm', 'x_0': '0', 'y_0': '0'}
-    area_extent = (5575000, 5575000, 5570000, 5570000)
-    width = 10
-    height = 10
-    geos_area = create_test_area(projection, width, height, area_extent)
-    return geos_area
-
-
-class TestGeostationaryTools:
-    """Test the geostationary bbox tools."""
-
-    def test_get_full_geostationary_bbox(self, truncated_geos_area):
-        nb_points = 20
-        x, y = get_full_geostationary_bounding_box_in_proj_coords(truncated_geos_area, nb_points)
-        assert len(x) == nb_points
-        assert len(y) == nb_points
-
-        assert x[0] != x[-1]
-        assert y[0] != y[-1]
-
-        expected_x = np.array([-5.43062255e+06, -5.16482897e+06, -4.39346593e+06, -3.19203985e+06,
-                               -1.67815466e+06, 3.32529726e-10, 1.67815466e+06, 3.19203985e+06,
-                               4.39346593e+06, 5.16482897e+06, 5.43062255e+06, 5.16482897e+06,
-                               4.39346593e+06, 3.19203985e+06, 1.67815466e+06, 3.32529726e-10,
-                               -1.67815466e+06, -3.19203985e+06, -4.39346593e+06, -5.16482897e+06])
-
-        expected_y = np.array([6.62789871e-10, 1.67242779e+06, 3.18114670e+06, 4.37847280e+06,
-                               5.14720348e+06, 5.41209002e+06, 5.14720348e+06, 4.37847280e+06,
-                               3.18114670e+06, 1.67242779e+06, -0.00000000e+00, -1.67242779e+06,
-                               -3.18114670e+06, -4.37847280e+06, -5.14720348e+06, -5.41209002e+06,
-                               -5.14720348e+06, -4.37847280e+06, -3.18114670e+06, -1.67242779e+06])
-
-        np.testing.assert_allclose(x, expected_x)
-        np.testing.assert_allclose(y, expected_y)
-
-    def test_get_geostationary_bbox_works_with_truncated_area(self, truncated_geos_area):
-        """Ensure the geostationary bbox works when truncated."""
-        lon, lat = get_geostationary_bounding_box_in_lonlats(truncated_geos_area, 20)
-
-        expected_lon = np.array(
-            [-64.24072434653284, -68.69662326361153, -65.92516214783112, -60.726360278290336,
-             -47.39851775032484, 9.500000000000018, 66.39851775032487, 79.72636027829033,
-             84.92516214783113, 87.69662326361151, 83.24072434653286])
-        expected_lat = np.array(
-            [14.554922655532085, 17.768795771961937, 35.34328897185421, 52.597860701318254, 69.00533141646078,
-             79.1481121862375, 69.00533141646076, 52.597860701318254, 35.34328897185421, 17.768795771961933,
-             14.554922655532085])
-        np.testing.assert_allclose(lon, expected_lon)
-        np.testing.assert_allclose(lat, expected_lat)
-
-    def test_get_geostationary_bbox_works_with_truncated_area_proj_coords(self, truncated_geos_area):
-        """Ensure the geostationary bbox works when truncated."""
-        x, y = get_geostationary_bounding_box_in_proj_coords(truncated_geos_area, 20)
-
-        expected_x = np.array(
-            [-5209128.302753595, -5164828.965702432, -4393465.934674804, -3192039.8468840676, -1678154.6586309497,
-             3.325297262895822e-10, 1678154.6586309501, 3192039.846884068, 4393465.934674805, 5164828.965702432,
-             5209128.302753594])
-        expected_y = np.array(
-            [1393687.2705, 1672427.7900638399, 3181146.6955466354, 4378472.798117005, 5147203.47659387,
-             5412090.016106332, 5147203.476593869, 4378472.798117005, 3181146.695546635, 1672427.7900638392,
-             1393687.2705])
-
-        np.testing.assert_allclose(x, expected_x)
-        np.testing.assert_allclose(y, expected_y)
-
-    def test_get_geostationary_bbox_does_not_contain_inf(self, truncated_geos_area):
-        """Ensure the geostationary bbox does not contain np.inf."""
-        lon, lat = get_geostationary_bounding_box_in_lonlats(truncated_geos_area, 20)
-        assert not any(np.isinf(lon))
-        assert not any(np.isinf(lat))
-
-    def test_get_geostationary_bbox_returns_empty_lonlats_in_space(self, truncated_geos_area_in_space):
-        """Ensure the geostationary bbox is empty when in space."""
-        lon, lat = get_geostationary_bounding_box_in_lonlats(truncated_geos_area_in_space, 20)
-
-        assert len(lon) == 0
-        assert len(lat) == 0
-
-    def test_get_geostationary_bbox(self):
-        """Get the geostationary bbox."""
-        geos_area = MagicMock()
-        lon_0 = 0
-        proj_dict = {'a': 6378169.00,
-                     'b': 6356583.80,
-                     'h': 35785831.00,
-                     'lon_0': lon_0,
-                     'proj': 'geos'}
-        geos_area.crs = CRS(proj_dict)
-        geos_area.area_extent = [-5500000., -5500000., 5500000., 5500000.]
-
-        lon, lat = get_geostationary_bounding_box_in_lonlats(geos_area, 20)
-        expected_lon = np.array([-78.19662326, -75.42516215, -70.22636028,
-                                 -56.89851775, 0., 56.89851775, 70.22636028,
-                                 75.42516215, 78.19662326, 79.23372832, 78.19662326,
-                                 75.42516215, 70.22636028, 56.89851775, 0.,
-                                 -56.89851775, -70.22636028, -75.42516215, -78.19662326, -79.23372832, ])
-        expected_lat = np.array([17.76879577, 35.34328897, 52.5978607,
-                                 69.00533142, 79.14811219, 69.00533142, 52.5978607,
-                                 35.34328897, 17.76879577, -0., -17.76879577,
-                                 -35.34328897, -52.5978607, -69.00533142, -79.14811219,
-                                 -69.00533142, -52.5978607, -35.34328897, -17.76879577, 0.])
-
-        np.testing.assert_allclose(lon, expected_lon, atol=1e-07)
-        np.testing.assert_allclose(lat, expected_lat, atol=1e-07)
-
-        geos_area = MagicMock()
-        lon_0 = 10
-        proj_dict = {'a': 6378169.00,
-                     'b': 6356583.80,
-                     'h': 35785831.00,
-                     'lon_0': lon_0,
-                     'proj': 'geos'}
-        geos_area.crs = CRS(proj_dict)
-        geos_area.area_extent = [-5500000., -5500000., 5500000., 5500000.]
-
-        lon, lat = get_geostationary_bounding_box_in_lonlats(geos_area, 20)
-        np.testing.assert_allclose(lon, expected_lon + lon_0)
-
-    def test_get_geostationary_angle_extent(self):
-        """Get max geostationary angles."""
-        geos_area = MagicMock()
-        proj_dict = {
-            'proj': 'geos',
-            'sweep': 'x',
-            'lon_0': -89.5,
-            'a': 6378169.00,
-            'b': 6356583.80,
-            'h': 35785831.00,
-            'units': 'm'}
-        geos_area.crs = CRS(proj_dict)
-
-        expected = (0.15185342867090912, 0.15133555510297725)
-        np.testing.assert_allclose(expected,
-                                   get_geostationary_angle_extent(geos_area))
-
-        proj_dict['a'] = 1000.0
-        proj_dict['b'] = 1000.0
-        proj_dict['h'] = np.sqrt(2) * 1000.0 - 1000.0
-        geos_area.crs = CRS(proj_dict)
-
-        expected = (np.deg2rad(45), np.deg2rad(45))
-        np.testing.assert_allclose(expected,
-                                   get_geostationary_angle_extent(geos_area))
-
-        proj_dict = {
-            'proj': 'geos',
-            'sweep': 'x',
-            'lon_0': -89.5,
-            'ellps': 'GRS80',
-            'h': 35785831.00,
-            'units': 'm'}
-        geos_area.crs = CRS(proj_dict)
-        expected = (0.15185277703584374, 0.15133971368991794)
-        np.testing.assert_allclose(expected,
-                                   get_geostationary_angle_extent(geos_area))
-
-
 class TestCrop:
     """Test the area helpers."""
 
@@ -1814,6 +1614,18 @@ class TestAreaDefGetAreaSlices:
         assert slice_lines == expected_slice_lines
         assert slice_cols == expected_slice_cols
 
+    def test_non_geos_can_be_cropped(self, create_test_area):
+        """Test that non-geos areas can be cropped also."""
+        src_area = create_test_area(dict(proj="utm", zone=33),
+                                    10980, 10980,
+                                    (499980.0, 6490200.0, 609780.0, 6600000.0))
+        crop_area = create_test_area({'proj': 'latlong'},
+                                     100, 100,
+                                     (15.9689, 58.5284, 16.4346, 58.6995))
+        slice_x, slice_y = src_area.get_area_slices(crop_area)
+        assert slice_x == slice(5630, 8339)
+        assert slice_y == slice(9261, 10980)
+
     def test_area_to_cover_all_nan_bounds(self, geos_src_area, create_test_area):
         """Check area slicing when the target doesn't have a valid boundary."""
         area_def = geos_src_area
@@ -1825,161 +1637,85 @@ class TestAreaDefGetAreaSlices:
         with pytest.raises(NotImplementedError):
             area_def.get_area_slices(area_to_cover)
 
+    @pytest.mark.parametrize("cache_slices", [False, True])
+    def test_area_slices_caching(self, create_test_area, tmp_path, cache_slices):
+        """Check that area slices can be cached."""
+        src_area = create_test_area(dict(proj="utm", zone=33),
+                                    10980, 10980,
+                                    (499980.0, 6490200.0, 609780.0, 6600000.0))
+        crop_area = create_test_area({'proj': 'latlong'},
+                                     100, 100,
+                                     (15.9689, 58.5284, 16.4346, 58.6995))
+        cache_glob = str(tmp_path / "geometry_slices_v1" / "*.json")
+        with pyresample.config.set(cache_dir=tmp_path, cache_geometry_slices=cache_slices):
+            assert len(glob(cache_glob)) == 0
+            slice_x, slice_y = src_area.get_area_slices(crop_area)
+            assert len(glob(cache_glob)) == int(cache_slices)
+        assert slice_x == slice(5630, 8339)
+        assert slice_y == slice(9261, 10980)
 
-class TestBoundary:
-    """Test 'boundary' method for AreaDefinition classes."""
+        if cache_slices:
+            from pyresample.future.geometry._subset import get_area_slices
+            with pyresample.config.set(cache_dir=tmp_path):
+                get_area_slices.cache_clear()
+            assert len(glob(cache_glob)) == 0
 
-    def test_polar_south_pole_projection(self, create_test_area):
-        """Test boundary for polar projection around the South Pole."""
-        areadef = create_test_area(
-            {'proj': 'laea', 'lat_0': -90, 'lon_0': 0, 'a': 6371228.0, 'units': 'm'},
-            2, 2,
-            (-5326849.0625, -5326849.0625, 5326849.0625, 5326849.0625),
-        )
-        boundary = areadef.boundary(force_clockwise=False)
+    def test_area_slices_caching_no_swaths(self, tmp_path, create_test_area, create_test_swath):
+        """Test that swath inputs produce a warning when tried to use in caching."""
+        from pyresample.future.geometry._subset import get_area_slices
+        from pyresample.test.utils import create_test_latitude, create_test_longitude
+        area = create_test_area(dict(proj="utm", zone=33),
+                                10980, 10980,
+                                (499980.0, 6490200.0, 609780.0, 6600000.0))
+        lons = create_test_longitude(-95.0, -75.0, shape=(1000, 500))
+        lats = create_test_latitude(25.0, 35.0, shape=(1000, 500))
+        swath = create_test_swath(lons, lats)
 
-        # Check boundary shape
-        height, width = areadef.shape
-        n_vertices = (width - 1) * 2 + (height - 1) * 2
-        assert boundary.vertices.shape == (n_vertices, 2)
+        with pyresample.config.set(cache_dir=tmp_path, cache_geometry_slices=True), pytest.raises(NotImplementedError):
+            with pytest.warns(UserWarning, match="unhashable"):
+                get_area_slices(swath, area, None)
 
-        # Check boundary vertices is in correct order
-        expected_vertices = np.array([[-45., -55.61313895],
-                                      [45., -55.61313895],
-                                      [135., -55.61313895],
-                                      [-135., -55.61313895]])
-        np.testing.assert_allclose(expected_vertices, boundary.vertices)
+    @pytest.mark.parametrize("swath_as_src", [False, True])
+    def test_unsupported_slice_inputs(self, create_test_area, create_test_swath, swath_as_src):
+        """Test that swath inputs produce an error."""
+        from pyresample.future.geometry._subset import get_area_slices
+        from pyresample.test.utils import create_test_latitude, create_test_longitude
+        area = create_test_area(dict(proj="utm", zone=33),
+                                10980, 10980,
+                                (499980.0, 6490200.0, 609780.0, 6600000.0))
+        lons = create_test_longitude(-95.0, -75.0, shape=(1000, 500))
+        lats = create_test_latitude(25.0, 35.0, shape=(1000, 500))
+        swath = create_test_swath(lons, lats)
 
-    def test_nort_pole_projection(self, create_test_area):
-        """Test boundary for polar projection around the North Pole."""
-        areadef = create_test_area(
-            {'proj': 'laea', 'lat_0': 90, 'lon_0': 0, 'a': 6371228.0, 'units': 'm'},
-            2, 2,
-            (-5326849.0625, -5326849.0625, 5326849.0625, 5326849.0625),
-        )
-        boundary = areadef.boundary(force_clockwise=False)
+        with pytest.raises(NotImplementedError):
+            args = (swath, area) if swath_as_src else (area, swath)
+            get_area_slices(*args, None)
 
-        # Check boundary shape
-        height, width = areadef.shape
-        n_vertices = (width - 1) * 2 + (height - 1) * 2
-        assert boundary.vertices.shape == (n_vertices, 2)
 
-        # Check boundary vertices is in correct order
-        expected_vertices = np.array([[-135., 55.61313895],
-                                      [135., 55.61313895],
-                                      [45., 55.61313895],
-                                      [-45., 55.61313895]])
-        np.testing.assert_allclose(expected_vertices, boundary.vertices)
+def test_future_to_legacy_conversion():
+    """Test that future AreaDefinitions can be converted to legacy areas."""
+    area_def = AreaDefinition(
+        {
+            'a': '6378144.0',
+            'b': '6356759.0',
+            'lat_0': '50.00',
+            'lat_ts': '50.00',
+            'lon_0': '8.00',
+            'proj': 'stere'
+        },
+        (800, 800),
+        (-1370912.72, -909968.64000000001, 1029087.28, 1490031.3600000001),
+        attrs={"name": 'areaD'},
+    )
+    legacy_area = area_def.to_legacy()
+    assert isinstance(legacy_area, LegacyAreaDefinition)
+    assert legacy_area.area_extent == area_def.area_extent
+    assert legacy_area.crs == area_def.crs
+    assert legacy_area.area_id == area_def.attrs["name"]
 
-    def test_geostationary_projection(self, create_test_area):
-        """Test boundary for geostationary projection."""
-        areadef = create_test_area(
-            {'a': 6378169.00, 'b': 6356583.80, 'h': 35785831.00, 'lon_0': 0, 'proj': 'geos'},
-            100, 100,
-            (-5500000., -5500000., 5500000., 5500000.),
-        )
 
-        # Check default boundary shape
-        default_n_vertices = 50
-        boundary = areadef.boundary(frequency=None)
-        assert boundary.vertices.shape == (default_n_vertices, 2)
-
-        # Check minimum boundary vertices
-        n_vertices = 3
-        minimum_n_vertices = 4
-        boundary = areadef.boundary(frequency=n_vertices)
-        assert boundary.vertices.shape == (minimum_n_vertices, 2)
-
-        # Check odd frequency number
-        # - Rounded to the sequent even number (to construct the sides)
-        n_odd_vertices = 5
-        boundary = areadef.boundary(frequency=n_odd_vertices)
-        assert boundary.vertices.shape == (n_odd_vertices + 1, 2)
-
-        # Check boundary vertices
-        n_vertices = 10
-        boundary = areadef.boundary(frequency=n_vertices, force_clockwise=False)
-
-        # Check boundary vertices is in correct order
-        expected_vertices = np.array([[-7.54251621e+01, 3.53432890e+01],
-                                      [-5.68985178e+01, 6.90053314e+01],
-                                      [5.68985178e+01, 6.90053314e+01],
-                                      [7.54251621e+01, 3.53432890e+01],
-                                      [7.92337283e+01, -0.00000000e+00],
-                                      [7.54251621e+01, -3.53432890e+01],
-                                      [5.68985178e+01, -6.90053314e+01],
-                                      [-5.68985178e+01, -6.90053314e+01],
-                                      [-7.54251621e+01, -3.53432890e+01],
-                                      [-7.92337283e+01, 6.94302533e-15]])
-        np.testing.assert_allclose(expected_vertices, boundary.vertices)
-
-    def test_global_platee_caree_projection(self, create_test_area):
-        """Test boundary for global platee caree projection."""
-        areadef = create_test_area(
-            'EPSG:4326',
-            4, 4,
-            (-180.0, -90.0, 180.0, 90.0),
-        )
-        boundary = areadef.boundary(force_clockwise=False)
-
-        # Check boundary shape
-        height, width = areadef.shape
-        n_vertices = (width - 1) * 2 + (height - 1) * 2
-        assert boundary.vertices.shape == (n_vertices, 2)
-
-        # Check boundary vertices is in correct order
-        expected_vertices = np.array([[-135., 67.5],
-                                      [-45., 67.5],
-                                      [45., 67.5],
-                                      [135., 67.5],
-                                      [135., 22.5],
-                                      [135., -22.5],
-                                      [135., -67.5],
-                                      [45., -67.5],
-                                      [-45., -67.5],
-                                      [-135., -67.5],
-                                      [-135., -22.5],
-                                      [-135., 22.5]])
-        np.testing.assert_allclose(expected_vertices, boundary.vertices)
-
-    def test_minimal_global_platee_caree_projection(self, create_test_area):
-        """Test boundary for global platee caree projection."""
-        areadef = create_test_area(
-            'EPSG:4326',
-            2, 2,
-            (-180.0, -90.0, 180.0, 90.0),
-        )
-        boundary = areadef.boundary(force_clockwise=False)
-
-        # Check boundary shape
-        height, width = areadef.shape
-        n_vertices = (width - 1) * 2 + (height - 1) * 2
-        assert boundary.vertices.shape == (n_vertices, 2)
-
-        # Check boundary vertices is in correct order
-        expected_vertices = np.array([[-90., 45.],
-                                      [90., 45.],
-                                      [90., -45.],
-                                      [-90., -45.]])
-        np.testing.assert_allclose(expected_vertices, boundary.vertices)
-
-    def test_local_area_projection(self, create_test_area):
-        """Test local area projection in meter."""
-        areadef = create_test_area(
-            'EPSG:2056',
-            2, 2,
-            (2_600_000.0, 1_050_000, 2_800_000.0, 1_170_000),
-        )
-        boundary = areadef.boundary(force_clockwise=False)
-
-        # Check boundary shape
-        height, width = areadef.shape
-        n_vertices = (width - 1) * 2 + (height - 1) * 2
-        assert boundary.vertices.shape == (n_vertices, 2)
-
-        # Check boundary vertices is in correct order
-        expected_vertices = np.array([[8.08993639, 46.41074744],
-                                      [9.39028624, 46.39582417],
-                                      [9.37106733, 45.85619242],
-                                      [8.08352612, 45.87097006]])
-        assert np.allclose(expected_vertices, boundary.vertices)
+@pytest.mark.parametrize("shape", [(100,), (100, 100, 100)])
+def test_non2d_shape_error(shape):
+    """Test that non-2D shapes fail."""
+    with pytest.raises(NotImplementedError):
+        AreaDefinition("EPSG:4326", shape, (-1000.0, -1000.0, 1000.0, 1000.0))
